==> cscec5b-rmat-api-3.0.1-20221110.031426-84-sources.jar: com/ejianc/business/rmat/vo/ExitApplyGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 退场申请单推送供方vo
 *
 * @Author
 * @Date
 **/
public class ExitApplyGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitDesc; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
    private Long linkId; // 联系人
    private String linkName; // 联系人
    private String sysmark;
    private String linkTelephone; // 联系人电话
    private List<ExitApplyDetailGFVO> exitApplyDetails = new ArrayList<>(); // 退场单明细

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public Long getLinkId() {
        return linkId;
    }

    public void setLinkId(Long linkId) {
        this.linkId = linkId;
    }

    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }

    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitDesc() {
        return exitDesc;
    }

    public void setExitDesc(String exitDesc) {
        this.exitDesc = exitDesc;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }

    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public List<ExitApplyDetailGFVO> getExitApplyDetails() {
        return exitApplyDetails;
    }

    public void setExitApplyDetails(List<ExitApplyDetailGFVO> exitApplyDetails) {
        this.exitApplyDetails = exitApplyDetails;
    }
}

==> cscec5b-rmat-api-3.0.1-20250120.044216-341-sources.jar: com/ejianc/business/rmat/vo/ExitApplyGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 退场申请单推送供方vo
 *
 * @Author
 * @Date
 **/
public class ExitApplyGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitDesc; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
    private Long linkId; // 联系人
    private String linkName; // 联系人
    private String sysmark;
    private String linkTelephone; // 联系人电话
    private Long corpId; // 项目所属组织id
    private String corpName; // 项目所属组织名称
    private String corpSourceId; // 项目所属组织来源id
    private List<ExitApplyDetailGFVO> exitApplyDetails = new ArrayList<>(); // 退场单明细

    public Long getCorpId() {
        return corpId;
    }

    public void setCorpId(Long corpId) {
        this.corpId = corpId;
    }

    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }

    public String getCorpSourceId() {
        return corpSourceId;
    }

    public void setCorpSourceId(String corpSourceId) {
        this.corpSourceId = corpSourceId;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public Long getLinkId() {
        return linkId;
    }

    public void setLinkId(Long linkId) {
        this.linkId = linkId;
    }

    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }

    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitDesc() {
        return exitDesc;
    }

    public void setExitDesc(String exitDesc) {
        this.exitDesc = exitDesc;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }

    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public List<ExitApplyDetailGFVO> getExitApplyDetails() {
        return exitApplyDetails;
    }

    public void setExitApplyDetails(List<ExitApplyDetailGFVO> exitApplyDetails) {
        this.exitApplyDetails = exitApplyDetails;
    }
}
